diff --git a/debian/changelog b/debian/changelog
index 33febaf..8aa86db 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -1,3 +1,13 @@
+s390-tools (2.12.0-0ubuntu3.2) focal; urgency=medium
+
+  * debian/patches/s390-tools-sru-lp1903984-focal.patch
+    zcryptstats: Fix handling of partial results with many domains
+    - zconf/zcrypt/zcryptstats.c: code fix to pass the correct next-domain
+      to the subsequent CHSC call of a partial response
+    Thanks to Ingo Franzki <ifranzki@linux.ibm.com>
+
+ -- Frank Heimes <frank.heimes@canonical.com>  Mon, 18 Jan 2021 21:56:31 +0100
+
 s390-tools (2.12.0-0ubuntu3.1) focal; urgency=medium
 
   * debian/patches/0082-*.patch .. 0111-*.patch (LP: #1892350)
diff --git a/debian/patches/s390-tools-sru-lp1903984-focal.patch b/debian/patches/s390-tools-sru-lp1903984-focal.patch
new file mode 100644
index 0000000..99994be
--- /dev/null
+++ b/debian/patches/s390-tools-sru-lp1903984-focal.patch
@@ -0,0 +1,48 @@
+Description: zcryptstats fails
+ The zcryptstats tool reports data for only the last two domain IDs.
+ Further, it hangs if one collect data for a complete crypto card,
+ and then one has to kill the ssh session to get back.
+ Patch/commit is:
+ cf2311f cf2311f1f1de17435b49ba8c8697be91705ba031
+ "zcryptstats: Fix handling of partial results with many domains"
+Author: Ingo Franzki <ifranzki@linux.ibm.com>
+Origin: backport
+Bug-IBM: IBM Bugzilla 189183
+Bug-Ubuntu: https://bugs.launchpad.net/bugs/1903984
+Forwarded: not-needed
+Applied-Upstream: upstream patch/commits:
+ https://github.com/ibm-s390-tools/s390-tools/commit/cf2311f1f1de17435b49ba8c8697be91705ba031
+Reviewed-by: Frank Heimes <frank.heimes@canonical.com>
+Last-Update: 2021-01-18
+---
+This patch header follows DEP-3: http://dep.debian.net/deps/dep3/
+--- a/zconf/zcrypt/zcryptstats.c
++++ b/zconf/zcrypt/zcryptstats.c
+@@ -1178,8 +1178,14 @@
+ 		scdmd_area.request.header.code = 0x102d;
+ 		scdmd_area.request.header.length =
+ 				sizeof(struct chsc_scdmd_request);
+-		scdmd_area.request.first_drid.ap_index = card;
+-		scdmd_area.request.first_drid.domain_index = g.min_domain;
++		if (scdmd_area.response.p) {
++			scdmd_area.request.first_drid =
++						scdmd_area.response.crid;
++		} else {
++			scdmd_area.request.first_drid.ap_index = card;
++			scdmd_area.request.first_drid.domain_index =
++								g.min_domain;
++		}
+ 		scdmd_area.request.last_drid.ap_index = card;
+ 		scdmd_area.request.last_drid.domain_index = g.max_domain;
+ 		scdmd_area.request.s = 1;
+@@ -1217,10 +1223,6 @@
+ 		rc = process_apqn_measurement_data(&scdmd_area);
+ 		if (rc != 0)
+ 			break;
+-
+-		if (scdmd_area.response.p)
+-			scdmd_area.request.first_drid =
+-					scdmd_area.response.crid;
+ 	} while (scdmd_area.response.p);
+ 
+ 	return rc;
diff --git a/debian/patches/series b/debian/patches/series
index e779db8..92c0d51 100644
--- a/debian/patches/series
+++ b/debian/patches/series
@@ -110,3 +110,4 @@ f742ed73e1db99dc04b821a1f9aa4a852584e4d8.patch
 0110-zipl-stage3-correctly-handle-diag308-response-code.patch
 0111-zipl-fix-incorrect-setup-of-stage3-flags.patch
 0112-cpumf-lscpumf.pl-displays-raw-event-number-incorrect.patch
+s390-tools-sru-lp1903984-focal.patch
